@@ -12,6 +12,8 @@
 #' @param version \code{integer} (or any other convertible class), defaults to
 #' \code{1L}. Specifies desired GIMMS NDVI3g product version, see 'Details'.
 #' Currently ignored if \code{server = "nasanex"}.
+#' @param quiet \code{logical}, defaults to \code{FALSE}. If \code{TRUE},
+#' console output is disabled.
 #'
 #' @return
 #' A \code{character} vector of online filepaths.
@@ -31,9 +33,17 @@
 #' updateInventory(version = 0) # NDVI3g.v0
 #' }
 #'
+#' ## note that local versions of the online file inventories are also available
+#' ofl_v1 <- system.file("extdata", "inventory_ecv1.rds", package = "gimms")
+#' readRDS(ofl_v1)
+#'
+#' ofl_v0 <- system.file("extdata", "inventory_ecv0.rds", package = "gimms")
+#' readRDS(ofl_v0)
+#'
 #' @export updateInventory
 #' @name updateInventory
-updateInventory <- function(server = c("ecocast", "nasanex"), version = 1L) {
+updateInventory <- function(server = c("ecocast", "nasanex"), version = 1L,
+                            quiet = FALSE) {
 
   ## available files (online)
   is_ecocast <- server[1] == "ecocast"
@@ -41,15 +51,17 @@ updateInventory <- function(server = c("ecocast", "nasanex"), version = 1L) {
 
   ## if first-choice server is not available, try alternative server
   if (class(fls) == "try-error" & length(server) == 2) {
-    cat("Priority server ('", server[1],
-        "') is not available. Contacting alternative server ('", server[2],
-        "').\n", sep = "")
+    if (!quiet)
+      cat("Priority server ('", server[1],
+          "') is not available. Contacting alternative server ('", server[2],
+          "').\n", sep = "")
     fls <- if (is_ecocast) updateNasanex() else updateEcocast(version)
   }
 
   ## available files (offline)
   if (class(fls) == "try-error") {
-    cat("Failed to retrieve online information. Using local file inventory...\n")
+    if (!quiet)
+      cat("Failed to retrieve online information. Using local file inventory...\n")
 
     fls <- if (server[1] == "nasanex") {
       readRDS(system.file("extdata", "inventory_nnv0.rds", package = "gimms"))
